@@ -1,9 +1,7 @@
-from dataclasses import dataclass
 from typing import Dict, List
 from aws_lambda_utils import BaseModelOptionalFields
 
 
-@dataclass
 class APIGatewayProxyResponse(BaseModelOptionalFields):
     StatusCode: int
     Headers: Dict[str, str]
